@@ -16,7 +16,7 @@ use Log::Log4perl::Appender;
 
 use constant _INTERNAL_DEBUG => 1;
 
-our $VERSION = '1.16';
+our $VERSION = '1.19';
 
    # set this to '1' if you're using a wrapper
    # around Log::Log4perl
@@ -100,8 +100,6 @@ sub import {
 
     if(exists $tags{':levels'}) {
         # Export log levels ($DEBUG, $INFO etc.) from Log4perl::Level
-        my $caller_pkg = caller();
-
         for my $key (keys %Log::Log4perl::Level::PRIORITY) {
             my $name  = "$caller_pkg\::$key";
                # Need to split this up in two lines, or CVS will
@@ -354,12 +352,12 @@ sub get_logger {  # Get an instance (shortcut)
 
     if(@_ == 0) {
           # 1
-        $category = scalar caller();
+        $category = scalar caller($Log::Log4perl::caller_depth);
     } elsif(@_ == 1) {
           # 2, 3
         if($_[0] eq __PACKAGE__) {
               # 2
-            $category = scalar caller();
+            $category = scalar caller($Log::Log4perl::caller_depth);
         } else {
             $category = $_[0];
         }
@@ -429,8 +427,9 @@ sub appender_by_name {  # Get an appender by name
 
     my($name) = @_;
 
-    if(exists $Log::Log4perl::Logger::APPENDER_BY_NAME{
-                $name}) {
+    if(defined $name and
+       exists $Log::Log4perl::Logger::APPENDER_BY_NAME{
+                 $name}) {
         return $Log::Log4perl::Logger::APPENDER_BY_NAME{
                  $name}->{appender};
     } else {
@@ -755,6 +754,17 @@ just chain together to a single string. Therefore
 
 are identical.
 
+Note that even if one of the methods above returns true, it doesn't 
+necessarily mean that the message will actually get logged. 
+What is_debug() checks is that
+the logger used is configured to let a message of the given priority 
+(DEBUG) through. But after this check, Log4perl will eventually apply custom 
+filters and forward the message to one or more appenders. None of this
+gets checked by is_xxx(), for the simple reason that it's 
+impossible to know what a custom filter does with a message without
+having the actual message or what an appender does to a message without
+actually having it log it.
+
 =head2 Log and die or warn
 
 Often, when you croak / carp / warn / die, you want to log those messages.
@@ -1133,6 +1143,8 @@ value of the filter function.
 
 =head1 Categories
 
+B<Categories are also called "Loggers" in Log4perl, both refer
+to the the same thing and these terms are used interchangeably.>
 C<Log::Log4perl> uses I<categories> to determine if a log statement in
 a component should be executed or suppressed at the current logging level.
 Most of the time, these categories are just the classes the log statements
@@ -1526,6 +1538,21 @@ this damaged configuration will be loaded during runtime, triggered
 either by a signal or if the delay period expired and the change is 
 detected. This behaviour might change in the future.
 
+To allow the application to intercept and control a configuration reload
+in init_and_watch mode, a callback can be specified:
+
+    Log::Log4perl->init_and_watch($conf_file, 10, { 
+            preinit_callback => \&callback });
+
+If Log4perl determines that the configuration needs to be reloaded, it will
+call the C<preinit_callback> function without parameters. If the callback
+returns a true value, Log4perl will proceed and reload the configuration.  If
+the callback returns a false value, Log4perl will keep the old configuration
+and skip reloading it until the next time around.  Inside the callback, an
+application can run all kinds of checks, including accessing the configuration
+file, which is available via
+C<Log::Log4perl::Config-E<gt>watcher()-E<gt>file()>.
+
 =head2 Variable Substitution
 
 To avoid having to retype the same expressions over and over again,
@@ -1811,7 +1838,7 @@ You'd do such as follows:
 And that's it! create_custom_level() creates the following functions /
 variables for level FOO:
 
-    $FOO_INT        # integer to use in toLevel()
+    $FOO_INT        # integer to use in L4p::Level::to_level()
     $logger->foo()  # log function to log if level = FOO
     $logger->is_foo()   # true if current level is >= FOO
 
@@ -2572,14 +2599,15 @@ our
 
     Contributors (in alphabetical order):
     Ateeq Altaf, Cory Bennett, Jeremy Bopp, Hutton Davidson, Chris R.
-    Donnelly, Matisse Enzer, Hugh Esco, James FitzGibbon, Carl Franks,
-    Dennis Gregorovic, Paul Harrington, David Hull, Robert Jacobson,
-    Jeff Macdonald, Markus Peter, Brett Rann, Erik Selberg, Aaron
-    Straup Cope, Lars Thegler, David Viner, Mac Yang.
+    Donnelly, Matisse Enzer, Hugh Esco, Anthony Foiani, James
+    FitzGibbon, Carl Franks, Dennis Gregorovic, Andy Grundman, Paul
+    Harrington, David Hull, Robert Jacobson, Jeff Macdonald, Markus
+    Peter, Brett Rann, Peter Rabbitson, Erik Selberg, Aaron Straup
+    Cope, Lars Thegler, David Viner, Mac Yang.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2007 by Mike Schilli E<lt>m@perlmeister.comE<gt> and Kevin Goess
+Copyright 2002-2008 by Mike Schilli E<lt>m@perlmeister.comE<gt> and Kevin Goess
 E<lt>cpan@goess.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
